import qrcode
import subprocess
import sys


def main():
    pass


if sys.platform == "darwin":
    try:
        ssid = (
            subprocess.check_output(
                "/System/Library/PrivateFrameworks/Apple80211.framework"
                "/Versions/Current/Resources/airport"
                " -I | sed -n 's/ *SSID: //p'",
                shell=True,
            )
            .decode()
            .strip()
        )

        auth = (
            subprocess.check_output(
                "/System/Library/PrivateFrameworks/Apple80211.framework"
                "/Versions/Current/Resources/airport"
                " -I | sed -n 's/ *link auth: //p'",
                shell=True,
            )
            .decode()
            .strip()
            .lower()
        )
        if "wpa" in auth:
            auth = "WPA"
        if "wep" in auth:
            auth = "WEP"

        password = (
            subprocess.check_output(
                "security find-generic-password -l"
                f"{ssid} -D 'AirPort network password' -w",
                shell=True,
            )
            .decode()
            .strip()
        )
    except Exception:
        sys.exit(1)
else:
    print("Your OS is not yet supported because I don't know how to get the auth type.")
    print("Please create an issue on Github.")

qr = qrcode.QRCode(version=1, border=4)
qr.add_data(f"WIFI:S:{ssid};T:{auth};P:{password};")
qr.print_ascii(tty=True)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['qrwifi']

package_data = \
{'': ['*']}

install_requires = \
['qrcode>=7.3.1,<8.0.0']

entry_points = \
{'console_scripts': ['qrwifi = qrwifi.__main__:main']}

setup_kwargs = {
    'name': 'qrwifi',
    'version': '0.1.1',
    'description': '',
    'long_description': '# qrwifi\n\nDisplay a QR code for your wifi in the terminal.\n\nCurrently only supports macOS. Create an issue if you want me to support your OS.\n\n## Installation\n\n```\npip install qrwifi\n```\n\n## Usage\n\n```\nqrwifi\n```',
    'author': 'Louis Abraham',
    'author_email': 'louis.abraham@yahoo.fr',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
